Proof

Struct Proof 

pub struct Proof { /* private fields */ }
Proof is complex crypto structure created by prover over multiple credentials that allows to prove that prover:

  1. Knows signature over credentials issued with specific issuer keys (identified by key id)
  2. Credential contains attributes with specific values that prover wants to disclose
  3. Credential contains attributes with valid predicates that verifier wants the prover to satisfy.