Verifier

Struct Verifier 

pub struct Verifier {}
Party that wants to check that prover has some credentials provided by issuer.

Implementations

Source

impl Verifier

pub fn new_sub_proof_request_builder() -> IndyCryptoResult<SubProofRequestBuilder>

Creates and returns sub proof request entity builder. Part of proof request related to a particular schema-key.

The purpose of sub proof request builder is building of sub proof request entity that represents requested attributes and predicates.

Example
use indy_crypto::cl::verifier::Verifier;

let mut sub_proof_request_builder = Verifier::new_sub_proof_request_builder().unwrap();
sub_proof_request_builder.add_revealed_attr("name").unwrap();
sub_proof_request_builder.add_predicate("age", "GE", 18).unwrap();
let _sub_proof_request = sub_proof_request_builder.finalize().unwrap();
pub fn new_proof_verifier() -> IndyCryptoResult<ProofVerifier>

Creates and returns proof verifier.

The purpose of proof verifier is check proof provided by Prover.

Example
use indy_crypto::cl::verifier::Verifier;

let _proof_verifier = Verifier::new_proof_verifier().unwrap();