get_exponentiated_generators

Function get_exponentiated_generators 

pub fn get_exponentiated_generators(
    to_exponentiate: Vec<(&BigNumber, &BigNumber)>,
    modulus: &BigNumber,
    ctx: &mut BigNumberContext,
) -> IndyCryptoResult<BigNumber>
Exponentiate the given generators to corresponding exponents

Arguments

  • to_exponentiate - a list of 2-tuples where the first element of the tuple is a generator and the second is the exponent, like [(g_1, e_1), (g_2, e_2), (g_3, e_3), … (g_i, e_i)]
  • modulus - all computations are done this modulo
  • ctx - big number context

Result

Return the exponentiation, i.e (g_1^e_1)*(g_2^e_2)*...(g_i^e_i)