pub struct Proof { /* private fields */ }Expand description
Proof is complex crypto structure created by prover over multiple credentials that allows to prove that prover:
- Knows signature over credentials issued with specific issuer keys (identified by key id)
- Credential contains attributes with specific values that prover wants to disclose
- Credential contains attributes with valid predicates that verifier wants the prover to satisfy.